#!/bin/bash
########################################################################
## Script    : cert-cainit.sh 
## Name      : 認証局の証明書管理環境初期化スクリプト
## Version   : 0.0.1
## Copyright : 2018-2019  Nomura Kei
## License   : BSD-2-Clause
## Usage:
## |使用法) cert-cainit.sh [オプション]
## |
## |  認証局の証明書管理環境を初期化します。
## |
## |[オプション]
## |  -h,--help      使用法を表示します。
## |  -v,--version   バージョンを表示します。
## |
##
########################################################################
SCRIPT_FILE=${0}
SCRIPT_DIR=`dirname ${SCRIPT_FILE}`
DIR=${SCRIPT_DIR}/..


########################################################################
##
## ライブラリのロード
##
[ -f "${SCRIPT_DIR}/functions.sh" ] && . ${SCRIPT_DIR}/functions.sh


# ======================================================================
#  指定されたパスに証明書生成環境を生成します。
#  具体的には、次の処理を実施します。
#  (0) 設定ファイルの修正 (dir の設定)
#  (1) 必要なディレクトリを作成
#  (2) ディレクトリの権限を設定
#  (3) 証明書のインデックス管理用ファイル作成
#  (4) 証明書のシリアル番号管理ファイル作成
#  (5) 失効リスト番号管理ファイル作成
#
#  @param $1 証明書生成環境を生成するパス
# ======================================================================
function cert_cainit() {
	# (0)
	BASE_DIR=`getAbsolutePath ${SCRIPT_DIR}/..`
	BASE_DIR_E=`echo "${BASE_DIR}" | sed "s/\//\\\\\\\\\\\\//g"`
echo "BASE_DIR_E=${BASE_DIR_E}"
echo "cp -f ${BASE_DIR}/conf/openssl.cnf ${BASE_DIR}/conf/openssl.cnf.old"
	cp -f ${BASE_DIR}/conf/openssl.cnf ${BASE_DIR}/conf/openssl.cnf.old
	sed "s/^\(dir.*=\s\+\).*\(\s\+#.*\)/\1${BASE_DIR_E}\2/" ${BASE_DIR}/conf/openssl.cnf.old > ${BASE_DIR}/conf/openssl.cnf

	mkdir -p ${DIR}/{certs,crl,newcerts,private}    # (1)
	chmod 700 ${DIR}/private                        # (2)
	if [ -f ${DIR}/index.txt ]; then
		mv -f ${DIR}/index.txt ${DIR}/index.txt.old
	fi
	cat /dev/null > ${DIR}/index.txt				# (3)
	if [ -f ${DIR}/serial ]; then
		mv -f ${DIR}/serial ${DIR}/serial.old
	fi
	echo 01 > ${DIR}/serial                         # (4)
	if [ -f ${DIR}/crlnumber ]; then
		mv -f ${DIR}/crlnumber ${DIR}/crlnumber.old
	fi
	echo 00 > ${DIR}/crlnumber                      # (5)

	MSG_PATH=`getAbsolutePath ${DIR}`
	echo "${MSG_PATH} に証明書生成環境を初期化しました。"
}



########################################################################
##
## メイン処理
##
for OPT in "$@"; do
	case "${OPT}" in
		'-h'|'--help')		usage;							exit 1	;;
		'-v'|'--version')	version;						exit 1	;;
		-*)
			usage
			exit 1
			;;
		*)
			if [[ ! -z "$1" ]] && [[ ! "$1" =~ ^-+ ]]; then
				usage
				exit 1
			fi
			;;
	esac
done

echo "1. 認証局の証明書管理環境を初期化します。"
confirm "   継続してよろしいですか？" 1
if [ $? -eq 0 ]; then
	exit 1
fi
cert_cainit

echo ""
echo "2. 秘密鍵を生成します。"
confirm "   継続してよろしいですか？" 1
if [ $? -eq 0 ]; then
	exit 1
fi
${SCRIPT_DIR}/cert-mkkey.sh

echo ""
echo "3. CSR (証明書署名要求) を作成します。"
confirm "   継続してよろしいですか？" 1
if [ $? -eq 0 ]; then
	exit 1
fi
${SCRIPT_DIR}/cert-mkcsr.sh

echo ""
echo "4. 自己署名します。"
confirm "   継続してよろしいですか？" 1
if [ $? -eq 0 ]; then
	exit 1
fi
${SCRIPT_DIR}/cert-sign.sh --type rootca ${SCRIPT_DIR}/../request.csr

