#!/bin/bash
########################################################################
## Script    : cert-mkpkcs12.sh
## Name      : pkcs12 作成スクリプト
## Version   : 0.0.1
## Copyright : 2018-2019  Nomura Kei
## License   : BSD-2-Clause
## Usage:
## |使用法) cert-mkpkcs12.sh [オプション] crtfile keyfile name
## |
## |  pkcs12 を作成します。
## |  証明書と秘密鍵をペアにして pkcs12 形式のファイルを生成します。
## |
## |  certfile  証明書
## |  keyfile   秘密鍵
## |  name      名前
## |
## |[オプション]
## |  --cacert args  CA証明書
## |                 (default: 指定なし)
## |  -h,--help      使用法を表示します。
## |  -v,--version   バージョンを表示します。
## |
##
########################################################################
SCRIPT_FILE=${0}
SCRIPT_DIR=`dirname ${SCRIPT_FILE}`
CACERT=
CRT=
NAME=
KEY=


########################################################################
##
## ライブラリのロード
##
[ -f "${SCRIPT_DIR}/functions.sh" ] && . ${SCRIPT_DIR}/functions.sh


# ======================================================================
#  引数をチェックします。
#  引数に問題がある場合、エラーを表示して終了します。
# ======================================================================
function checkArgs() {
	# 1.CRT チェック
	if [ "${CRT}" = "" ]; then
		echo "証明書(crtfile)[pem 形式]を指定してください。"
		exit 1
	fi
	# 2.KEY チェック
	if [ "${KEY}" = "" ]; then
		echo "秘密鍵(keyfile)を指定してください。"
		exit 1
	fi
	# 3.NAME チェック
	if [ "${NAME}" = "" ]; then
		echo "名前(name)を指定してください。"
		exit 1
	fi
}



# ======================================================================
#  秘密鍵を生成します。
#
#  @param $1 秘密鍵出力先
#  @param $2 暗号化アルゴリズム
# ======================================================================
function cert_mkpkcs12() {
	checkArgs
	OUTDIR=`dirname ${CRT}`
	OUTFILE="${OUTDIR}/output.p12"

	OPT_CACERT=
	if [ "${CACERT}" != "" ]; then
		OPT_CACERT="-cert ${CACERT}"
	fi
	openssl pkcs12 -export		\
		-in ${CRT}				\
		-inkey ${KEY}			\
		${OPT_CACERT}			\
		-out ${OUTFILE}			\
		-name "${NAME}"
}



########################################################################
##
## メイン処理
##
for OPT in "$@"; do
	case "${OPT}" in
		'-h'|'--help')		usage;								exit 1	;;
		'-v'|'--version')	version;							exit 1	;;
		'--cacert')			checkOptionArgs "$2"; CACERT="$2";	shift 2	;;
		-*)
			usage
			exit 1
			;;
		*)
			if [[ ! -z "$1" ]] && [[ ! "$1" =~ ^-+ ]]; then
				if [ "${CRT}" = "" ]; then
					CRT=("$1")
				elif [ "${KEY}" = "" ]; then
					KEY=("$1")
				else
					NAME=("$1")
				fi
				shift 1
			fi
			;;
	esac
done

cert_mkpkcs12

