#!/bin/bash
########################################################################
## Script    : cert-revoke.sh
## Name      : 失効証明書管理スクリプト
## Version   : 0.0.1
## Copyright : 2018-2019  Nomura Kei
## License   : BSD-2-Clause
## Usage:
## |使用法) cert-revoke.sh [オプション] 失効させる証明書
## |
## |  指定された証明書を失効させます。
## |                 
## |[オプション]
## |  --md arg      メッセージダイジェストを指定します。
## |                メッセージダイジェストとして次の値を指定可能です。
## |                  md4, md5, ripemd160, whirlpool
## |                  sha, sha1, sha224, sha256, sha384, sha512
## |                (default: --md sha256)
## |  --out arg     CRL 出力先を指定します。
## |                (default: --out crl/latestcrl.crl))
## |  -h,--help     使用法を表示します。
## |  -v,--version  バージョンを表示します。
## |
##
########################################################################
SCRIPT_FILE=${0}
SCRIPT_DIR=`dirname ${SCRIPT_FILE}`
CONF=${SCRIPT_DIR}/../conf/openssl.cnf
MD=sha256
OUT=${SCRIPT_DIR}/../crl/latestcrl.crl
TARGET=


########################################################################
##
## ライブラリのロード
##
[ -f "${SCRIPT_DIR}/functions.sh" ] && . ${SCRIPT_DIR}/functions.sh



# ======================================================================
#  引数をチェックします。
#  引数に問題がある場合、エラーを表示して終了します。
# ======================================================================
function checkArgs() {
	# 1. MD チェック
	if [ "${MD}" = "" ]; then
		echo "--md の指定に誤りがあります。"
		exit 1
	fi

	# 2. OUT チェック
	if [ "${OUT}" = "" ]; then
		echo "--out の指定に誤りがあります。"
		exit 1
	fi

	# 3. TARGET チェック
	if [ "${TARGET}" = "" ]; then
		echo "失効させる証明書を指定してください。"
		exit 1
	fi
}



# ======================================================================
#  証明書を失効させます。
# ======================================================================
function cert_revoke() {
	# 1. 引数チェック
	checkArgs

	# 2. 拡張設定ファイル生成 (サーバー証明書の場合のみ)
	openssl ca -gencrl	\
		-md ${MD}		\
		-config ${CONF}	\
		-revoke ${TARGET}
	if [ $? -eq 0 ]; then
		${SCRIPT_DIR}/cert-mkcrl.sh --out ${OUT}
	fi
}



########################################################################
##
## メイン処理
##
for OPT in "$@"; do
	case "${OPT}" in
		'-h'|'--help')		usage;								exit 1	;;
		'-v'|'--version')	version;							exit 1	;;
		'--md')				checkOptionArgs "$2"; MD="$2";		shift 2	;;
		'--out')			checkOptionArgs "$2"; OUT="$2";		shift 2	;;
		-*)
			usage
			exit 1
			;;
		*)
			if [[ ! -z "$1" ]] && [[ ! "$1" =~ ^-+ ]]; then
				TARGET=("$1")
				shift 1
			fi
			;;
	esac
done

cert_revoke

